Data Readers
============

LSL Developer Primitives
------------------------
.. automodule:: lsl.reader.ldp
   :members:

Low-Level TBW -- DP
-------------------
.. automodule:: lsl.reader.tbw
   :members:

Low-Level TBF -- ADP
--------------------
.. versionadded:: 1.2
.. automodule:: lsl.reader.tbf
   :members:

Low-Level TBN -- DP and ADP
---------------------------
.. automodule:: lsl.reader.tbn
   :members:

Low-Level COR -- ADP
--------------------
.. versionadded:: 1.2
.. automodule:: lsl.reader.cor
   :members:

Low-Level DRX -- DP and ADP
---------------------------
.. automodule:: lsl.reader.drx
   :members:

Low-Level DRX8 -- ADP
---------------------
.. automodule:: lsl.reader.drx8
   :members:

Low-Level DR Spectrometer -- DP and ADP
---------------------------------------
.. versionadded:: 0.5
.. automodule:: lsl.reader.drspec
   :members:

Low-Level VIDF
--------------
.. automodule:: lsl.reader.vdif
   :members:

Reader Error Codes
------------------
.. automodule:: lsl.reader.errors
   :members:

Reader Ring Buffer
==================
.. automodule:: lsl.reader.buffer
   :show-inheritance:
   :members:

